@@ -1,83 +1,97 @@
-from urllib import request
-from urllib.parse import urlparse
+__version__ = "4.9"
+
+from urllib import request as _request
+from urllib.parse import urlparse as _urlparse
+from ssl import _create_unverified_context
+from os.path import isfile as _isfile
 from .style import *
+from .extra import CaseInsensitiveDict
 
 
-class NoRedirects(request.HTTPRedirectHandler):
+class _NoRedirects(_request.HTTPRedirectHandler):
     """
-    Class to handle HTTP Rediect, to be installed via opener on request object.
+    Sub-class to handle HTTP Rediect, to be installed via opener on request object.
     """
     def redirect_request(self, req, fp, code, msg, headers, newurl):
-        return None
+        pass
 
 
 
-def validateUrl(url, color=True):
+def schemizeUrl(url, color=True, quiet=False):
     """
     Returns url string after adding scheme if not present, and modofying scheme if not http.
 
         Parameters:
             url (str): URL string
             color (bool): Shall color be printed while function is running
-        
+
         Returns:
             url (str): URL string after prepending or modifying scheme to http
     """
-    parsedUrl = urlparse(url)
+    parsedUrl = _urlparse(url)
     if not parsedUrl.scheme:
-        url = 'http://' + url
+        url = 'http'+'://' + url
     elif parsedUrl.scheme not in ('http', 'https'):
-        print(bad(f'Scheme `{parsedUrl.scheme}` does not looks like of `http`', color))
-        print(info('Scheme modified to `http`', color))
+        if not quiet:
+            print(bad(f'Scheme `{parsedUrl.scheme}` does not looks like of `http`', color))
+            print(info('Scheme modified to `http`', color))
         url = url.split('://')
         url[0] = 'http'
         url = '://'.join(url)
     return url
 
 
-def getHeaders(url, noRedirects=False, color=True):
+def getHeaders(url, noRedirects=False, insecure=False, color=True, quiet=False):
     """
-    Returns HTTP Headers of a queried URL.
+    Returns HTTP Headers of a queried URL with a GET HTTP request.
 
         Parameters:
             url (str): URL string
             noRedirects (bool): Shall redirection be followed
+            insecure (bool): Ignore TLS/SSL warnings
             color (bool): Shall color be printed while function is running
-        
+
         Returns:
             headers (dict): HTTP Headers of a queried URL
     """
     try:
         if noRedirects:
-            opener = request.build_opener(NoRedirects)
-            request.install_opener(opener)
-        req = request.Request(
+            opener = _request.build_opener(_NoRedirects)
+            _request.install_opener(opener)
+        req = _request.Request(
                                 url,
                                 data=None,
-                                headers={'User-Agent': 'sech3r/4.2'}
+                                headers={'User-Agent': f'sech3r/{__version__}'}
                             )
-        resp = request.urlopen(req)
+        if not insecure or url.startswith('http'+'://'):
+            resp = _request.urlopen(req)
+        else:
+            resp = _request.urlopen(req, context=_create_unverified_context())
         if resp.url != url:
-            if resp.url.startswith('https://'):
-                print(good(f'Redirected to -> {resp.url}', color))
-            else:
-                print(info(f'Redirected to -> {resp.url}', color))
+            if not quiet:
+                if resp.url.startswith('https://'):
+                    print(good(f'Redirected to -> {resp.url}', color))
+                else:
+                    print(info(f'Redirected to -> {resp.url}', color))
     except Exception as excptn:
-        print(bad(str(excptn).replace(': ', ' -> '), color))
+        if not quiet:
+            print(bad(str(excptn).replace(': ', ' -> '), color))
+        else:
+            print(f'ERROR: {excptn}')
         if 'HTTP Error' in str(excptn):
             resp = excptn
         else:
             return {}
-    return dict(resp.headers)
+    return CaseInsensitiveDict(resp.headers)
 
 
-def checkSecHeads(headers):
+def checkSecurityHeaders(headers):
     """
     Check for Security Headers.
 
         Parameters:
             headers (dict): HTTP Headers
-        
+
         Returns:
             headersPresent (dict): HTTP security headers present with it's values
             headersNotPresent (list): HTTP security headers not present
@@ -106,13 +120,13 @@ def checkSecHeads(headers):
     return headersPresent, headersNotPresent
 
 
-def checkInfoHeads(headers):
+def checkInformativeHeaders(headers):
     """
-    Check for Informative Headers.
+    Check for Informative Headers, like version disclosure.
 
         Parameters:
             headers (dict): HTTP Headers
-        
+
         Returns:
             disclosedOnes (dict): Informative HTTP headers with disclosed version
             undisclosedOnes (dict): Informative HTTP headers with version not disclosed
@@ -125,7 +139,7 @@ def checkInfoHeads(headers):
     disclosedOnes = {}
     undisclosedOnes = {}
     for header in version_disclosure_headers:
-        if header in headers.keys():
+        if header in headers:
             if any(char.isdigit() for char in headers[header]):
                 disclosedOnes[header] = headers[header]
             else:
@@ -133,3 +147,8 @@ def checkInfoHeads(headers):
     return disclosedOnes, undisclosedOnes
 
 
+def read_url_from_file(filename):
+    if filename:
+        if _isfile(filename):
+            with open(filename) as input_file:
+                return input_file.read().strip().split('\n')
